@@ -9,13 +9,22 @@ function(Amat, r){
     
     one.pos <- which(Amat!=0, arr.ind = TRUE)
     zero.pos <- which(Amat==0, arr.ind = TRUE)
-    
+
     zero.pos <- zero.pos[which(zero.pos[,1] > zero.pos[,2]) ,]
-    sel.zero <- sample(seq(1, dim(zero.pos)[1]), r * dim(zero.pos)[1], replace = FALSE) 
-    zeroMat[zero.pos[sel.zero, ]] <- 1
-    zeroMat <- zeroMat + t(zeroMat)  
-    zeroArr <- zero.pos[sel.zero, ]
-    
+    if (length(zero.pos)==0){
+      warning("The matrix is zero!")
+      zeroMat <- matrix(0, p, p)
+      zeroArr <- NULL
+    } else{
+      if (is.null(dim(zero.pos))){
+        zero.pos <- matrix(zero.pos, nrow = 1)
+      }
+      sel.zero <- sample(seq(1, nrow(zero.pos)), r * nrow(zero.pos), replace = FALSE) 
+      zeroMat[zero.pos[sel.zero, ]] <- 1
+      zeroMat <- zeroMat + t(zeroMat)  
+      zeroArr <- zero.pos[sel.zero, ]
+      
+    }
     out <- list()
     out$zeroArr = zeroArr
     out$zeroMat = zeroMat
@@ -29,8 +38,7 @@ function(Amat, r){
       if (is.null(dim(one.pos))){
         one.pos = matrix(one.pos, nrow = 1)
       }
-      
-      sel.one <- sample(seq(1, dim(one.pos)[1]), r * dim(one.pos)[1], replace = FALSE) 
+      sel.one <- sample(seq(1, nrow(one.pos)), r * nrow(one.pos), replace = FALSE) 
       oneMat[one.pos[sel.one, ]] <- 1
       oneMat <- oneMat + t(oneMat)
       diag(oneMat) <- 0
